<?php
/*
Plugin Name: Coupon XL Custom Post Types
Plugin URI: http://demo.powerthemes.club/themes/couponxl/
Description: Coupon XL custom post types and taxonomies
Version: 3.0
Author: pebas
Author URI: http://themeforest.net/user/pebas/
License: GNU General Public License version 3.0
*/

define( 'COUPONXL_CPT_DIR', plugin_dir_path( __FILE__ ) );

if ( ! function_exists( 'couponxl_post_types_and_taxonomies' ) ) {
	function couponxl_post_types_and_taxonomies() {
		$offer_args = array(
			'labels'      => array(
				'name'          => __( 'Offers', 'couponxl' ),
				'singular_name' => __( 'Offer', 'couponxl' )
			),
			'public'      => true,
			'menu_icon'   => 'dashicons-megaphone',
			'has_archive' => false,
			'supports'    => array(
				'title',
				'editor',
				'thumbnail',
				'author',
				'excerpt',
				'comments'
			)
		);
		if ( class_exists( 'ReduxFramework' ) && function_exists( 'couponxl_get_option' ) ) {
			$trans_offer = couponxl_get_option( 'trans_offer' );
			if ( ! empty( $trans_offer ) ) {
				$offer_args['rewrite'] = array( 'slug' => $trans_offer );
			}
		}
		register_post_type( 'offer', $offer_args );

		$location_args = array(
			'label'        => __( 'Location', 'couponxl' ),
			'hierarchical' => true,
			'labels'       => array(
				'name'                       => __( 'Location', 'couponxl' ),
				'singular_name'              => __( 'Location', 'couponxl' ),
				'menu_name'                  => __( 'Location', 'couponxl' ),
				'all_items'                  => __( 'All Locations', 'couponxl' ),
				'edit_item'                  => __( 'Edit Location', 'couponxl' ),
				'view_item'                  => __( 'View Location', 'couponxl' ),
				'update_item'                => __( 'Update Location', 'couponxl' ),
				'add_new_item'               => __( 'Add New Location', 'couponxl' ),
				'new_item_name'              => __( 'New Location Name', 'couponxl' ),
				'parent_item'                => __( 'Parent Location', 'couponxl' ),
				'parent_item_colon'          => __( 'Parent Location:', 'couponxl' ),
				'search_items'               => __( 'Search Locations', 'couponxl' ),
				'popular_items'              => __( 'Popular Locations', 'couponxl' ),
				'separate_items_with_commas' => __( 'Separate locations with commas', 'couponxl' ),
				'add_or_remove_items'        => __( 'Add or remove locations', 'couponxl' ),
				'choose_from_most_used'      => __( 'Choose from the most used locations', 'couponxl' ),
				'not_found'                  => __( 'No locations found', 'couponxl' ),
				'show_in_rest'               => true
			)

		);
		if ( class_exists( 'ReduxFramework' ) && function_exists( 'couponxl_get_option' ) ) {
			$trans_location = couponxl_get_option( 'trans_location' );
			if ( ! empty( $trans_location ) ) {
				$location_args['rewrite'] = array( 'slug' => $trans_location );
			}
		}
		register_taxonomy( 'location', array( 'offer' ), $location_args );

		$offer_cat_args = array(
			'label'        => __( 'Offer Categories', 'couponxl' ),
			'hierarchical' => true,
			'labels'       => array(
				'name'                       => __( 'Offer Categories', 'couponxl' ),
				'singular_name'              => __( 'Offer Category', 'couponxl' ),
				'menu_name'                  => __( 'Offer Category', 'couponxl' ),
				'all_items'                  => __( 'All Offer Categories', 'couponxl' ),
				'edit_item'                  => __( 'Edit Offer Category', 'couponxl' ),
				'view_item'                  => __( 'View Offer Category', 'couponxl' ),
				'update_item'                => __( 'Update Offer Category', 'couponxl' ),
				'add_new_item'               => __( 'Add New Offer Category', 'couponxl' ),
				'new_item_name'              => __( 'New Offer Category Name', 'couponxl' ),
				'parent_item'                => __( 'Parent Offer Category', 'couponxl' ),
				'parent_item_colon'          => __( 'Parent Offer Category:', 'couponxl' ),
				'search_items'               => __( 'Search Offer Categories', 'couponxl' ),
				'popular_items'              => __( 'Popular Offer Categories', 'couponxl' ),
				'separate_items_with_commas' => __( 'Separate offer categories with commas', 'couponxl' ),
				'add_or_remove_items'        => __( 'Add or remove offer categories', 'couponxl' ),
				'choose_from_most_used'      => __( 'Choose from the most used offer categories', 'couponxl' ),
				'not_found'                  => __( 'No offer categories found', 'couponxl' ),
			)

		);
		if ( class_exists( 'ReduxFramework' ) && function_exists( 'couponxl_get_option' ) ) {
			$trans_offer_cat = couponxl_get_option( 'trans_offer_cat' );
			if ( ! empty( $trans_offer_cat ) ) {
				$offer_cat_args['rewrite'] = array( 'slug' => $trans_offer_cat );
			}
		}
		register_taxonomy( 'offer_cat', array( 'offer' ), $offer_cat_args );

		$offer_tag_args = array(
			'label'        => __( 'Offer Tags', 'couponxl' ),
			'hierarchical' => false,
			'labels'       => array(
				'name'                       => __( 'Offer Tags', 'couponxl' ),
				'singular_name'              => __( 'Offer Tag', 'couponxl' ),
				'menu_name'                  => __( 'Offer Tag', 'couponxl' ),
				'all_items'                  => __( 'All Offer Tags', 'couponxl' ),
				'edit_item'                  => __( 'Edit Offer Tag', 'couponxl' ),
				'view_item'                  => __( 'View Offer Tag', 'couponxl' ),
				'update_item'                => __( 'Update Offer Tag', 'couponxl' ),
				'add_new_item'               => __( 'Add New Offer Tag', 'couponxl' ),
				'new_item_name'              => __( 'New Offer Tag Name', 'couponxl' ),
				'parent_item'                => __( 'Parent Offer Tag', 'couponxl' ),
				'parent_item_colon'          => __( 'Parent Offer Tag:', 'couponxl' ),
				'search_items'               => __( 'Search Offer Tags', 'couponxl' ),
				'popular_items'              => __( 'Popular Offer Tags', 'couponxl' ),
				'separate_items_with_commas' => __( 'Separate offer tags with commas', 'couponxl' ),
				'add_or_remove_items'        => __( 'Add or remove offer tags', 'couponxl' ),
				'choose_from_most_used'      => __( 'Choose from the most used offer tags', 'couponxl' ),
				'not_found'                  => __( 'No offer tags found', 'couponxl' ),
			)

		);
		if ( class_exists( 'ReduxFramework' ) && function_exists( 'couponxl_get_option' ) ) {
			$trans_offer_tag = couponxl_get_option( 'trans_offer_tag' );
			if ( ! empty( $trans_offer_tag ) ) {
				$offer_tag_args['rewrite'] = array( 'slug' => $trans_offer_tag );
			}
		}
		register_taxonomy( 'offer_tag', array( 'offer' ), $offer_tag_args );

		$store_args = array(
			'labels'       => array(
				'name'          => __( 'Stores', 'couponxl' ),
				'singular_name' => __( 'Store', 'couponxl' )
			),
			'public'       => true,
			'menu_icon'    => 'dashicons-store',
			'has_archive'  => false,
			'supports'     => array(
				'title',
				'editor',
				'thumbnail'
			),
			'show_in_rest' => true
		);
		if ( class_exists( 'ReduxFramework' ) && function_exists( 'couponxl_get_option' ) ) {
			$trans_store = couponxl_get_option( 'trans_store' );
			if ( ! empty( $trans_store ) ) {
				$store_args['rewrite'] = array( 'slug' => $trans_store );
			}
		}
		register_post_type( 'store', $store_args );

		$letter_args = array(
			'label'        => __( 'Letters', 'couponxl' ),
			'hierarchical' => true,
			'labels'       => array(
				'name'                       => __( 'Letters', 'couponxl' ),
				'singular_name'              => __( 'Letter', 'couponxl' ),
				'menu_name'                  => __( 'Letter', 'couponxl' ),
				'all_items'                  => __( 'All Letters', 'couponxl' ),
				'edit_item'                  => __( 'Edit Letter', 'couponxl' ),
				'view_item'                  => __( 'View Letter', 'couponxl' ),
				'update_item'                => __( 'Update Letter', 'couponxl' ),
				'add_new_item'               => __( 'Add New Letter', 'couponxl' ),
				'new_item_name'              => __( 'New Letter Name', 'couponxl' ),
				'parent_item'                => __( 'Parent Letter', 'couponxl' ),
				'parent_item_colon'          => __( 'Parent Letter:', 'couponxl' ),
				'search_items'               => __( 'Search Letters', 'couponxl' ),
				'popular_items'              => __( 'Popular Letters', 'couponxl' ),
				'separate_items_with_commas' => __( 'Separate letters with commas', 'couponxl' ),
				'add_or_remove_items'        => __( 'Add or remove letters', 'couponxl' ),
				'choose_from_most_used'      => __( 'Choose from the most used letters', 'couponxl' ),
				'not_found'                  => __( 'No letters found', 'couponxl' ),
			)

		);
		if ( class_exists( 'ReduxFramework' ) && function_exists( 'couponxl_get_option' ) ) {
			$trans_letter = couponxl_get_option( 'trans_letter' );
			if ( ! empty( $trans_letter ) ) {
				$letter_args['rewrite'] = array( 'slug' => $trans_letter );
			}
		}
		register_taxonomy( 'letter', array( 'store' ), $letter_args );

		register_post_type( 'voucher', array(
			'labels'       => array(
				'name'          => __( 'Vouchers', 'couponxl' ),
				'singular_name' => __( 'Voucher', 'couponxl' )
			),
			'public'       => true,
			'menu_icon'    => 'dashicons-tickets-alt',
			'has_archive'  => false,
			'supports'     => array(
				'title',
			),
			'capabilities' => array(
				'publish_posts'       => 'manage_options',
				'edit_posts'          => 'manage_options',
				'edit_others_posts'   => 'manage_options',
				'delete_posts'        => 'manage_options',
				'delete_others_posts' => 'manage_options',
				'read_private_posts'  => 'manage_options',
				'edit_post'           => 'manage_options',
				'delete_post'         => 'manage_options',
				'read_post'           => 'manage_options',
			),
		) );

		if ( class_exists( 'Seravo_Custom_Bulk_Action' ) ) {
			$bulk_actions = new Seravo_Custom_Bulk_Action( array( 'post_type' => 'voucher' ) );

			$bulk_actions->register_bulk_action( array(
				'menu_text'    => __( 'Pay To Sellers', 'couponxl' ),
				'admin_notice' => __( 'Sellers are paid', 'couponxl' ),
				'callback'     => function ( $post_ids ) {
					couponxl_pay_all_sellers( $post_ids, 'no' );

					return true;
				}
			) );

			$bulk_actions->init();
		}

	}
}
add_action( 'init', 'couponxl_post_types_and_taxonomies', 0 );

/* --------------------------------------------------------DISABLE BAR---------------------------------------------------*/
function couponxl_remove_admin_bar() {
	$user_ID    = get_current_user_id();
	$user_agent = get_user_meta( $user_ID, 'user_agent', true );
	if ( ! current_user_can( 'administrator' ) && ! is_admin() && ( ! $user_agent || $user_agent == 'no' ) ) {
		show_admin_bar( false );
	}
}

add_action( 'after_setup_theme', 'couponxl_remove_admin_bar' );

if ( ! function_exists( 'couponxl_cpt_share' ) ) {
	function couponxl_cpt_share() {
		?>
		<ul class="list-unstyled share-networks animation <?php echo is_singular( 'post' ) ? 'opened' : ''; ?>">
			<li>
				<a href="https://www.facebook.com/sharer/sharer.php?u=<?php echo urlencode( get_permalink() ) ?>"
				   class="share"
				   target="_blank">
					<i class="fa fa-facebook"></i>
				</a>
			</li>
			<li>
				<a href="https://twitter.com/intent/tweet?text=<?php echo urlencode( get_permalink() ) ?>" class="share"
				   target="_blank">
					<i class="fa fa-twitter"></i>
				</a>
			</li>
			<li>
				<a href="https://plus.google.com/share?url=<?php echo urlencode( get_permalink() ) ?>" class="share"
				   target="_blank">
					<i class="fa fa-google-plus"></i>
				</a>
			</li>
		</ul>

		<a href="javascript:" class="share open-share">
			<i class="fa fa-share-alt"></i>
		</a>
		<?php
	}
}

// Add custom meta boxes
/* MANAGE RATINGS */
function couponxl_ratings_box() {

	$screens = array( 'offer', 'post' );

	foreach ( $screens as $screen ) {
		add_meta_box( 'couponxl_ratings', __( 'Manage Ratings', 'couponxl' ), 'couponxl_ratings_box_populate',
			$screen );
	}
}

add_action( 'add_meta_boxes', 'couponxl_ratings_box' );

function couponxl_add_meta_box() {
	add_meta_box( 'offer_discussion', __( 'Offer Discussion', 'couponxl' ), 'couponxl_discussion_meta', 'offer' );
}

add_action( 'add_meta_boxes', 'couponxl_add_meta_box' );


/* DASHBOARD */
//add_action( 'wp_dashboard_setup', 'couponxl_dashboard_overview' );
function couponxl_dashboard_overview() {
	add_meta_box( 'couponxl_coupon_overall', __( 'Coupon', 'couponxl' ), 'couponxl_coupon_overall', 'dashboard', 'side',
		'high' );
	add_meta_box( 'couponxl_deal_overall', __( 'Deal', 'couponxl' ), 'couponxl_deal_overall', 'dashboard', 'side',
		'high' );
	add_meta_box( 'couponxl_user_overall', __( 'User', 'couponxl' ), 'couponxl_user_overall', 'dashboard', 'side',
		'high' );
	add_meta_box( 'couponxl_earnings_overall', __( 'Earnings', 'couponxl' ), 'couponxl_earnings_overall', 'dashboard',
		'side', 'high' );
}

add_action( 'wp_dashboard_setup', 'couponxl_dashboard_overview' );

function couponxl_return_tweets( $count = 1 ) {
	include_once( plugin_dir_path( __FILE__ ) . '/includes/twitter_api.php' );
	$username                  = couponxl_get_option( 'twitter-username' );
	$oauth_access_token        = couponxl_get_option( 'twitter-oauth_access_token' );
	$oauth_access_token_secret = couponxl_get_option( 'twitter-oauth_access_token_secret' );
	$consumer_key              = couponxl_get_option( 'twitter-consumer_key' );
	$consumer_secret           = couponxl_get_option( 'twitter-consumer_secret' );

	if ( ! empty( $username ) && ! empty( $oauth_access_token ) && ! empty( $oauth_access_token_secret ) && ! empty( $consumer_key ) && ! empty( $consumer_secret ) ) {
		$cache_file = dirname( __FILE__ ) . '/includes/' . 'twitter-cache.txt';
		if ( ! file_exists( $cache_file ) ) {
			file_put_contents( $cache_file, '' );
		}
		$modified = filemtime( $cache_file );
		$now      = time();
		$interval = 600; // ten minutes

		$response = json_decode( file_get_contents( $cache_file ), true );

		if ( ! $modified || empty( $response ) || ( ( $now - $modified ) > $interval ) || ! empty( $response['errors'] ) || ! empty( $response['error'] ) ) {
			$settings = array(
				'oauth_access_token'        => $oauth_access_token,
				'oauth_access_token_secret' => $oauth_access_token_secret,
				'consumer_key'              => $consumer_key,
				'consumer_secret'           => $consumer_secret,
				'username'                  => $username,
				'tweets'                    => $count
			);

			$twitter  = new TwitterAPIExchange( $settings );
			$response = $twitter->get_tweets();

			if ( $response ) {
				$cache_static = fopen( $cache_file, 'w' );
				fwrite( $cache_static, json_encode( $response ) );
				fclose( $cache_static );
			}
		}
	} else {
		$response = array( 'error' => 'NOK' );
	}

	return $response;
}

if ( ! function_exists( 'couponxl_recover_password_email' ) ) {
	function couponxl_recover_password_email() {
		$message = '';
		if ( isset( $_POST['recover_field'] ) ) {
			if ( wp_verify_nonce( $_POST['recover_field'], 'recover' ) ) {
				$email = $_POST['email'];
				if ( ! empty( $email ) ) {
					if ( filter_var( $email, FILTER_VALIDATE_EMAIL ) ) {
						if ( email_exists( $email ) ) {
							$user                  = get_user_by( 'email', $email );
							$new_password          = couponxl_random_string( 5 );
							$update_fields         = array(
								'ID'        => $user->ID,
								'user_pass' => $new_password,
							);
							$update_id             = wp_update_user( $update_fields );
							$lost_password_message = couponxl_get_option( 'lost_password_message' );
							$lost_password_message = str_replace( "%USERNAME%", $user->user_login,
								$lost_password_message );
							$lost_password_message = str_replace( "%PASSWORD%", $new_password, $lost_password_message );

							$email_sender = couponxl_get_option( 'email_sender' );
							$name_sender  = couponxl_get_option( 'name_sender' );
							$headers      = array();
							$headers[]    = "MIME-Version: 1.0";
							$headers[]    = "Content-Type: text/html; charset=UTF-8";
							$headers[]    = "From: " . $name_sender . " <" . $email_sender . ">";

							$lost_password_subject = couponxl_get_option( 'lost_password_subject' );

							$message_info = @wp_mail( $email, $lost_password_subject, $lost_password_message,
								$headers );
							if ( $message_info ) {
								$message = '<div class="alert alert-danger">' . __( 'Email with the new password and your username is sent to the provided email address',
										'couponxl' ) . '</div>';
							} else {
								$message = '<div class="alert alert-danger">' . __( 'There was an error trying to send an email',
										'couponxl' ) . '</div>';
							}
						} else {
							$message = '<div class="alert alert-danger">' . __( 'There is no user with the provided email address',
									'couponxl' ) . '</div>';
						}
					} else {
						$message = '<div class="alert alert-danger">' . __( 'Email address is invalid',
								'couponxl' ) . '</div>';
					}
				} else {
					$message = '<div class="alert alert-danger">' . __( 'Email address is empty',
							'couponxl' ) . '</div>';
				}
			} else {
				$message = '<div class="alert alert-danger">' . __( 'You do not permission for your action',
						'couponxl' ) . '</div>';
			}
		}

		return $message;

	}
}

function couponxl_send_contact() {
	$errors  = array();
	$name    = isset( $_POST['name'] ) ? esc_sql( $_POST['name'] ) : '';
	$email   = isset( $_POST['email'] ) ? esc_sql( $_POST['email'] ) : '';
	$message = isset( $_POST['message'] ) ? esc_sql( $_POST['message'] ) : '';
	if ( ! isset( $_POST['captcha'] ) ) {
		if ( ! empty( $name ) && ! empty( $email ) && ! empty( $message ) ) {
			if ( filter_var( $email, FILTER_VALIDATE_EMAIL ) ) {
				$email_to = couponxl_get_option( 'contact_mail' );
				$subject  = couponxl_get_option( 'contact_form_subject' );
				if ( ! empty( $email_to ) ) {
					$message = "
						" . __( 'Name: ', 'couponxl' ) . " {$name} \n
						" . __( 'Email: ', 'couponxl' ) . " {$email} \n
						" . __( 'Message: ', 'couponxl' ) . "\n {$message} \n
					";
					$info    = @wp_mail( $email_to, $subject, $message );
					if ( $info ) {
						echo json_encode( array(
							'success' => __( 'Your message was successfully submitted.', 'couponxl' ),
						) );
						die();
					} else {
						echo json_encode( array(
							'error' => __( 'Unexpected error while attempting to send e-mail.', 'couponxl' ),
						) );
						die();
					}
				} else {
					echo json_encode( array(
						'error' => __( 'Message is not send since the recepient email is not yet set.', 'couponxl' ),
					) );
					die();
				}
			} else {
				echo json_encode( array(
					'error' => __( 'Email is not valid.', 'couponxl' ),
				) );
				die();
			}
		} else {
			echo json_encode( array(
				'error' => __( 'All fields are required.', 'couponxl' ),
			) );
			die();
		}
	} else {
		echo json_encode( array(
			'error' => __( 'Captcha is wrong.', 'couponxl' ),
		) );
		die();
	}
}

add_action( 'wp_ajax_contact', 'couponxl_send_contact' );
add_action( 'wp_ajax_nopriv_contact', 'couponxl_send_contact' );

function couponxl_new_offer( $offer_id ) {
	$to      = couponxl_get_option( 'new_offer_email' );
	$message = __( 'New offer has been submited. You can edit it ', 'couponxl' ) . get_edit_post_link( $offer_id, '' );

	$info = @wp_mail( $to, __( 'New offer submited', 'couponxl' ), $message );

	return $info;
}

/* VOUCHER STATUS */
function couponxl_send_friend() {
	$frinds_email = isset( $_POST['frinds_email'] ) ? $_POST['frinds_email'] : '';
	$offer_id     = isset( $_POST['offer_id'] ) ? $_POST['offer_id'] : '';
	$your_message = isset( $_POST['your_message'] ) ? $_POST['your_message'] : '';
	if ( ! empty( $frinds_email ) && filter_var( $frinds_email, FILTER_VALIDATE_EMAIL ) ) {
		$headers   = array();
		$headers[] = "MIME-Version: 1.0";
		$headers[] = "Content-Type: text/html; charset=UTF-8";

		$from_mail = couponxl_get_option( 'email_sender' );
		$from_name = couponxl_get_option( 'name_sender' );
		$headers[] = "From: " . $from_name . " <" . $from_mail . ">";
		$subject   = couponxl_get_option( 'send_friend_subject' );

		$your_message .= "<br/>
-------------------------<br/>
" . get_permalink( $offer_id ) . "
";

		$info = @wp_mail( $frinds_email, $subject, $your_message, $headers );
		if ( $info ) {
			echo '<div class="alert alert-success">' . __( 'Your message has beens sent', 'couponxl' ) . '</div>';
		} else {
			echo '<div class="alert alert-danger">' . __( 'There was an error sending your mail',
					'couponxl' ) . '</div>';
		}
	} else {
		echo '<div class="alert alert-danger">' . __( 'Email is invalid', 'couponxl' ) . '</div>';
	}

	die();
}

add_action( 'wp_ajax_send_friend', 'couponxl_send_friend' );
add_action( 'wp_ajax_nopriv_send_friend', 'couponxl_send_friend' );

function couponxl_voucher_code_message( $offer, $voucher_buyer_id, $voucher_code ) {

	$headers   = array();
	$headers[] = "MIME-Version: 1.0";
	$headers[] = "Content-Type: text/html; charset=UTF-8";

	$user      = get_userdata( $voucher_buyer_id );
	$to        = $user->user_email;
	$from_mail = couponxl_get_option( 'email_sender' );
	$from_name = couponxl_get_option( 'name_sender' );

	$author    = get_userdata( $offer->post_author );
	$to_author = $author->user_email;

	$headers[] = "From: " . $from_name . " <" . $from_mail . ">";

	$deal_voucher_expire = get_post_meta( $offer->ID, 'deal_voucher_expire', true );
	$message             = couponxl_get_option( 'purchase_message' );
	$message             = str_replace( array( '%TITLE%', '%VOUCHER%' ), array(
		$offer->post_title,
		$voucher_code
	), $message );
	$message_expire_part = couponxl_get_option( 'purchase_message_expire' );
	if ( ! empty( $deal_voucher_expire ) ) {
		$deal_voucher_expire = date_i18n( 'F j, Y H:i', $deal_voucher_expire );
		$message             .= str_replace( '%EXPIRE%', $deal_voucher_expire, $message_expire_part );
	}

	$subject = couponxl_get_option( 'purchase_message_subject' );

	$info = @wp_mail( $to, $subject, $message, $headers );

	$author_subject = 'New offer sale!';
	$author_message = sprintf( 'Offer %s has been bought!', get_permalink( $offer->ID ) );
	$author_info    = @wp_mail( $to_author, $author_subject, $author_message, $headers );
}

function couponxl_send_admin_message( $message, $user_id = '' ) {
	$headers   = array();
	$headers[] = "MIME-Version: 1.0";
	$headers[] = "Content-Type: text/html; charset=UTF-8";

	if ( ! empty( $user_id ) ) {
		$user      = get_userdata( $user_id );
		$to        = $user->user_email;
		$from_mail = couponxl_get_option( 'discussion_form_mail' );
		$from_name = couponxl_get_option( 'discussion_form_mail_name' );
		$headers[] = "From: " . $from_name . " <" . $from_mail . ">";
	} else {
		$to = couponxl_get_option( 'discussion_form_mail' );
	}

	$subject = couponxl_get_option( 'discussion_form_subject' );

	$info = @wp_mail( $to, $subject, $message, $headers );

	return $info;
}

function couponxl_registration_email( $email, $username, $confirmation_hash ) {
	$confirmation_message = couponxl_get_option( 'registration_message' );
	$confirmation_link    = couponxl_get_permalink_by_tpl( 'page-tpl_register' );
	$confirmation_link    = couponxl_append_query_string( $confirmation_link, array(
		'username'          => $username,
		'confirmation_hash' => $confirmation_hash
	) );

	$confirmation_message = str_replace( '%LINK%', $confirmation_link, $confirmation_message );

	$registration_subject = couponxl_get_option( 'registration_subject' );

	$email_sender = couponxl_get_option( 'email_sender' );
	$name_sender  = couponxl_get_option( 'name_sender' );
	$headers      = array();
	$headers[]    = "MIME-Version: 1.0";
	$headers[]    = "Content-Type: text/html; charset=UTF-8";
	$headers[]    = "From: " . $name_sender . " <" . $email_sender . ">";

	$info = wp_mail( $email, $registration_subject, $confirmation_message, $headers );

	return $info;
}

function couponxl_send_email($email, $registration_subject, $confirmation_message, $headers) {
	$info = wp_mail( $email, $registration_subject, $confirmation_message, $headers );

	return $info;
}

/********************************************************
Add CouponXL Widgets
 ********************************************************/
function couponxl_widgets_load(){
	register_widget( 'Couponxl_Category' );
	register_widget( 'Couponxl_Locations' );
	register_widget( 'Couponxl_Popular_Stores' );
	register_widget( 'Couponxl_Custom_Stores' );
	register_widget( 'Couponxl_Latest_Posts_Comments' );
	register_widget( 'Couponxl_Latest_Posts' );
	register_widget( 'Couponxl_Custom_Locations' );
	register_widget( 'Couponxl_Custom_Menu' );
	register_widget( 'Couponxl_Custom_Menu_Two' );
	register_widget( 'CouponXL_Tweets' );
	register_widget( 'CouponXL_Shortcode_Text' );
	register_widget( 'CouponXL_Mega_Menu_Categories_List' );
	register_widget( 'CouponXL_Mega_Menu_Locations_List' );
	register_widget( 'CouponXL_Mega_Menu_Custom_List' );
	register_widget( 'CouponXL_Mega_Menu_Images' );
	register_widget( 'CouponXL_Subscribe' );
}
add_action( 'widgets_init', 'couponxl_widgets_load' );

function couponxl_pay_all_sellers( $vouchers = array(), $echo = 'yes' ) {
	global $wpdb;
	$sellers = array(
		'paypal' => array(),
		'stripe' => array(),
		'skrill' => array()
	);
	$args    = array(
		'post_type'      => 'voucher',
		'posts_per_page' => - 1,
		'post_status'    => 'publish',
		'meta_query'     => array(
			array(
				'key'     => 'voucher_payment_status',
				'value'   => 'not_paid',
				'compare' => '='
			)
		)
	);
	if ( ! empty( $_POST['voucher_id'] ) ) {
		$voucher = get_post( $_POST['voucher_id'] );
		if ( ! empty( $voucher ) ) {
			$args['post__in'] = array( $_POST['voucher_id'] );
		}
	} else if ( ! empty( $vouchers ) ) {
		$args['post__in'] = $vouchers;
	}
	$vouchers = get_posts( $args );
	if ( ! empty( $vouchers ) ) {
		foreach ( $vouchers as $voucher ) {
			$voucher_seller_id    = get_post_meta( $voucher->ID, 'voucher_seller_id', true );
			$seller_payout_method = get_user_meta( $voucher_seller_id, 'seller_payout_method', true );
			if ( ! empty( $seller_payout_method ) ) {
				switch ( $seller_payout_method ) {
					case 'paypal' :
						$seller_paypal_account = get_user_meta( $voucher_seller_id, 'seller_paypal_account', true );
						if ( empty( $sellers[ $seller_payout_method ][ $seller_paypal_account ] ) ) {
							$sellers[ $seller_payout_method ][ $seller_paypal_account ] = array(
								'amount'      => 0,
								'voucher_ids' => array(),
								'user'        => get_the_author_meta( 'user_login', $voucher_seller_id )
							);
						}
						$sellers[ $seller_payout_method ][ $seller_paypal_account ]['amount']        += get_post_meta( $voucher->ID, 'voucher_seller_share', true );
						$sellers[ $seller_payout_method ][ $seller_paypal_account ]['voucher_ids'][] = $voucher->ID;
						break;
					case 'stripe':
						$seller_stripe_data = get_user_meta( $voucher_seller_id, 'seller_stripe_data', true );
						if ( empty( $sellers[ $seller_payout_method ][ $seller_stripe_data['stripe_user_id'] ] ) ) {
							$sellers[ $seller_payout_method ][ $seller_stripe_data['stripe_user_id'] ] = array(
								'amount'      => 0,
								'voucher_ids' => array(),
								'user'        => get_the_author_meta( 'user_login', $voucher_seller_id )
							);
						}
						$sellers[ $seller_payout_method ][ $seller_stripe_data['stripe_user_id'] ]['amount']        += get_post_meta( $voucher->ID, 'voucher_seller_share', true );
						$sellers[ $seller_payout_method ][ $seller_stripe_data['stripe_user_id'] ]['voucher_ids'][] = $voucher->ID;
						break;
					case 'skrill':
						$seller_skrill_account = get_user_meta( $voucher_seller_id, 'seller_skrill_account', true );
						if ( empty( $sellers[ $seller_payout_method ][ $seller_skrill_account ] ) ) {
							$sellers[ $seller_payout_method ][ $seller_skrill_account ] = array(
								'amount'      => 0,
								'voucher_ids' => array(),
								'user'        => get_the_author_meta( 'user_login', $voucher_seller_id )
							);
						}
						$sellers[ $seller_payout_method ][ $seller_skrill_account ]['amount']        += get_post_meta( $voucher->ID, 'voucher_seller_share', true );
						$sellers[ $seller_payout_method ][ $seller_skrill_account ]['voucher_ids'][] = $voucher->ID;
				}
			}
		}
	}

	couponxl_pay_sellers( $sellers, $echo );
}

add_action( 'wp_ajax_pay_all_sellers', 'couponxl_pay_all_sellers' );
add_action( 'wp_ajax_nopriv_pay_all_sellers', 'couponxl_pay_all_sellers' );

function couponxl_write_ratings() {
	global $wpdb;
	$rate       = sanitize_text_field( $_POST['rate'] );
	$post_id    = sanitize_text_field( $_POST['post_id'] );
	$result     = couponxl_get_rate_average( $post_id );
	$avg        = get_post_meta( $post_id, 'couponxl_average_rate', true );
	$check_vote = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM {$wpdb->postmeta} WHERE post_id='%s' AND meta_key='couponxl_rating' AND meta_value LIKE '%s'", $post_id, $_SERVER['REMOTE_ADDR'] . '%' ) );
	if ( ! empty( $check_vote ) ) {
		$check_vote      = $check_vote[0];
		$temp            = explode( '|', $check_vote->meta_value );
		$old_value       = $temp[1];
		$result['sum']   -= $old_value;
		$result['count'] -= 1;
		delete_post_meta( $post_id, 'couponxl_rating', $check_vote->meta_value );
	}
	$wpdb->insert( $wpdb->postmeta, array(
		'post_id'    => $post_id,
		'meta_key'   => 'couponxl_rating',
		'meta_value' => $_SERVER['REMOTE_ADDR'] . '|' . $rate
	), array(
		'%d',
		'%s',
		'%s'
	) );

	$average = 0;
	$average = number_format( ( $result['sum'] + $rate ) / ( $result['count'] + 1 ), 2 );
	update_post_meta( $post_id, 'couponxl_average_rate', $average );

	$rate = couponxl_calculate_ratings( $post_id );

	wp_send_json_success( $rate );
}

add_action( 'wp_ajax_write_rate', 'couponxl_write_ratings' );
add_action( 'wp_ajax_nopriv_write_rate', 'couponxl_write_ratings' );

function couponxl_coupon_button( $post_id = '', $is_shortcode = false ) {
	global $couponxl_slugs;
	if ( empty( $post_id ) ) {
		$post_id = get_the_ID();
	}

	if ( $is_shortcode || is_front_page() ) {
		$base_permalink = couponxl_get_permalink_by_tpl( 'page-tpl_search_page' );
	} else {
		$base_permalink = is_ssl() ? 'https://' : 'http://' . "$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
	}

	$paged = '';
	if ( strpos( $base_permalink, '/page' ) ) {
		$paged          = explode( '/page', $base_permalink );
		$base_permalink = $paged[0];
	}
	if ( get_query_var( $couponxl_slugs['coupon'] ) && get_option( 'permalink_structure' ) ) {
		$end            = strrpos( $base_permalink, $couponxl_slugs['coupon'] );
		$base_permalink = substr( $base_permalink, 0, $end );
	}
	$coupon_type    = get_post_meta( $post_id, 'coupon_type', true );
	$affiliate_link = get_post_meta( $post_id, 'coupon_link', true );
	$coupon_link    = 'javascript:;';
	$target         = '';
	if ( ! empty( $affiliate_link ) ) {
		if ( ! empty( $paged[1] ) ) {
			$coupon_link .= 'page' . $paged[1];
		}
		$coupon_link = esc_url( $coupon_link );
		$coupon_link .= '#cpn-' . $post_id;
		$target      = 'target="_blank"';
	}

	$button = '<a href="' . $coupon_link . '" data-affiliate="' . esc_url( $affiliate_link ) . '" data-offer_id="' . esc_attr( $post_id ) . '" class="btn show-code" ' . $target . '>';

	switch ( $coupon_type ) {
		case 'code':
			$button .= '
				<i class="fa fa-scissors coupon-type"></i>
				' . __( 'SHOW CODE', 'couponxl' );
			break;
		case 'sale':
			$button .= '
				<i class="fa fa-chain coupon-type"></i>
				' . __( 'CHECK SALE', 'couponxl' );
			break;
		case 'printable':
			$button .= '
				<i class="fa fa-print coupon-type"></i>
				' . __( 'SHOW COUPON', 'couponxl' );
			break;
	}

	$button .= '</a>';

	return $button;
}

function couponxl_buy_pay_link( $offer_id, $buy_now, $generating, $permalink, $success_redirect, $cancel_redirect, $amount, $btn = true ) {
	$offer              = get_post( $offer_id );
	$payments_available = array();

	$currency = couponxl_get_option( 'main_unit_abbr' );

	$pk_client_id = couponxl_get_option( 'pk_client_id' );
	if ( ! empty( $pk_client_id ) ) {
		$payments_available['stripe'] = 'j';
	}

	$paypal_username = couponxl_get_option( 'paypal_username' );
	if ( ! empty( $paypal_username ) ) {
		$response                     = couponxl_generate_paypal_link( $amount, $offer->post_title, $offer->post_excerpt, uniqid( '', true ), $success_redirect, $cancel_redirect );
		$payments_available['paypal'] = ! isset( $response['error'] ) ? $response['url'] : 'javascript:;';
	}

	$skrill_owner_mail = couponxl_get_option( 'skrill_owner_mail' );
	if ( ! empty( $skrill_owner_mail ) ) {
		$payments_available['skrill'] = 'j';
	}


	$mollie_id = couponxl_get_option( 'mollie_id' );
	if ( ! empty( $mollie_id ) ) {
		$payments_available['ideal'] = 'j';
	}

	$payu_merchant_key = couponxl_get_option( 'payu_merchant_key' );
	if ( ! empty( $payu_merchant_key ) ) {
		$payments_available['payu'] = 'j';
	}

	if ( count( $payments_available ) == '1' ) {
		if ( ! empty( $payments_available['paypal'] ) ) {
			echo '<a href="' . $payments_available['paypal'] . '" class="btn">' . $buy_now . '</a>';
		} else if ( ! empty( $payments_available['stripe'] ) ) {
			$pk_client_id  = couponxl_get_option( 'pk_client_id' );
			$site_logo     = couponxl_get_option( 'site_logo' );
			$stripe_amount = $amount * 100;
			echo '<a href="javascript:;" class="' . ( $btn ? 'btn' : '' ) . ' stripe-payment" data-genearting_string="' . esc_attr( $generating ) . '"  data-pk="' . esc_attr( $pk_client_id ) . '" data-offer_id="' . esc_attr( $offer_id ) . '" data-name="'
			     . esc_attr( $offer->post_title ) . '" data-description="' . esc_attr( $offer->post_excerpt ) . '" data-amount="' . esc_attr( $stripe_amount ) . '" data-currency="' . esc_attr( $currency ) . '">' . $buy_now . '</a>';
		} else if ( ! empty( $payments_available['skrill'] ) ) {
			if ( $btn ) {
				$buyer_id   = get_current_user_id();
				$return_url = add_query_arg( array( 'skrill_return' => '1' ), get_permalink( $offer_id ) );
				$status_url = add_query_arg( array(
					'id_offer' => $offer_id,
					'buyer_id' => $buyer_id
				), home_url( '/' ) . 'index.php' );
			} else {
				$return_permalink = "http://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
				$return_url       = add_query_arg( array( 'skrill_return' => '1' ), $return_permalink );
				$status_url       = add_query_arg( array(
					'id_offer'     => $offer_id,
					'submit_offer' => '1'
				), home_url( '/' ) . 'index.php' );
			}
			echo '<a href="javascript:;" class="' . ( $btn ? 'btn' : '' ) . ' skrill-payment">' . $buy_now . '</a>' . couponxl_skrill_form( $amount, $currency, $offer_id, $offer->post_title, $return_url, $status_url );
		} else if ( ! empty( $payments_available['ideal'] ) ) {
			if ( $btn ) {
				$buyer_id   = get_current_user_id();
				$return_url = add_query_arg( array( 'ideal_return' => '1' ), get_permalink( $offer_id ) );
				$status_url = add_query_arg( array(
					'id_offer' => $offer_id,
					'buyer_id' => $buyer_id
				), home_url( '/' ) . 'index.php' );
			} else {
				$return_permalink = "http://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
				$return_url       = add_query_arg( array( 'ideal_return' => '1' ), $return_permalink );
				$status_url       = add_query_arg( array(
					'id_offer'     => $offer_id,
					'submit_offer' => '1'
				), home_url( '/' ) . 'index.php' );
			}
			echo couponxl_ideal_form( $amount, $currency, $offer_id, $offer->post_title, $return_url, $status_url ) . '<a href="javascript:;" class="' . ( $btn ? 'btn' : '' ) . ' submit-ideal-payment" data-genearting_string="' . esc_attr( $generating ) . '">'
			     . $buy_now . '</a>';
		} else if ( ! empty( $payments_available['payu'] ) ) {
			$buyer_id  = get_current_user_id();
			$is_submit = false;
			if ( $btn ) {
				$return_url = add_query_arg( array(
					'id_offer' => $offer_id,
					'buyer_id' => $buyer_id
				), get_permalink( $offer_id ) );
			} else {
				$return_permalink = "http://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
				$return_url       = add_query_arg( array(
					'id_offer'     => $offer_id,
					'submit_offer' => '1'
				), $return_permalink );
				$is_submit        = true;
			}
			echo '<a href="javascript:;" class="' . ( $btn ? 'btn' : '' ) . ' payu-initiate">' . $buy_now . '</a>' . couponxl_payu_form( $offer_id, $return_url, $is_submit );
		}
	} else {
		$modal = '';
		if ( ! empty( $payments_available['paypal'] ) ) {
			$modal .= '<div class="payment-method"><a href="' . $payments_available['paypal'] . '"><img src="' . get_template_directory_uri() . '/images/paypal.png" /></a></div>';
		}
		if ( ! empty( $payments_available['stripe'] ) ) {
			$pk_client_id  = couponxl_get_option( 'pk_client_id' );
			$site_logo     = couponxl_get_option( 'site_logo' );
			$stripe_amount = $amount * 100;
			$modal         .= '<div class="payment-method"><a href="javascript:;" class="stripe-payment" data-genearting_string="' . esc_attr( $generating ) . '" data-pk="' . esc_attr( $pk_client_id ) . '" data-offer_id="' . esc_attr( $offer_id )
			                  . '" data-image="' . esc_url( $site_logo['url'] ) . '" data-name="' . esc_attr( $offer->post_title ) . '" data-description="' . esc_attr( $offer->post_excerpt ) . '" data-amount="' . $stripe_amount . '" data-currency="'
			                  . esc_attr( $currency ) . '">
				<img src="' . get_template_directory_uri() . '/images/stripe.png" />
			</a></div>';
		}
		if ( ! empty( $payments_available['skrill'] ) ) {
			if ( $btn ) {
				$buyer_id   = get_current_user_id();
				$return_url = add_query_arg( array( 'skrill_return' => '1' ), get_permalink( $offer_id ) );
				$status_url = add_query_arg( array(
					'id_offer' => $offer_id,
					'buyer_id' => $buyer_id
				), home_url( '/' ) . 'index.php' );
			} else {
				$return_permalink = "http://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
				$return_url       = add_query_arg( array( 'skrill_return' => '1' ), $return_permalink );
				$status_url       = add_query_arg( array(
					'id_offer'     => $offer_id,
					'submit_offer' => '1'
				), home_url( '/' ) . 'index.php' );
			}
			$modal .= '<div class="payment-method"><a href="javascript:;" class="skrill-payment">
				<img src="' . get_template_directory_uri() . '/images/skrill.png" />
			</a>' . couponxl_skrill_form( $amount, $currency, $offer_id, $offer->post_title, $return_url, $status_url ) . '</div>';
		}
		if ( ! empty( $payments_available['ideal'] ) ) {
			if ( $btn ) {
				$buyer_id   = get_current_user_id();
				$return_url = add_query_arg( array( 'ideal_return' => '1' ), get_permalink( $offer_id ) );
				$status_url = add_query_arg( array(
					'id_offer' => $offer_id,
					'buyer_id' => $buyer_id
				), home_url( '/' ) . 'index.php' );
			} else {
				$return_permalink = "http://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
				$return_url       = add_query_arg( array( 'ideal_return' => '1' ), $return_permalink );
				$status_url       = add_query_arg( array(
					'id_offer'     => $offer_id,
					'submit_offer' => '1'
				), home_url( '/' ) . 'index.php' );
			}

			$modal .= '<div class="payment-method"><a href="javascript:;" class="submit-ideal-payment" data-genearting_string="' . esc_attr( $generating ) . '">
				<img src="' . get_template_directory_uri() . '/images/ideal.png" />
			</a>' . couponxl_ideal_form( $amount, $currency, $offer_id, $offer->post_title, $return_url, $status_url ) . '</div>';
		}
		if ( ! empty( $payments_available['payu'] ) ) {
			$buyer_id  = get_current_user_id();
			$is_submit = false;
			if ( $btn ) {
				$return_url = add_query_arg( array(
					'id_offer' => $offer_id,
					'buyer_id' => $buyer_id
				), get_permalink( $offer_id ) );
			} else {
				$return_permalink = "http://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";
				$return_url       = add_query_arg( array(
					'id_offer'     => $offer_id,
					'submit_offer' => '1'
				), $return_permalink );
				$is_submit        = true;
			}

			$modal .= '<div class="payment-method"><a href="javascript:;" class="payu-initiate">
				<img src="' . get_template_directory_uri() . '/images/payu.png" />
			</a>' . couponxl_payu_form( $offer_id, $return_url, $is_submit ) . '</div>';
		}
		$modal .= '<hr/><h4>' . __( 'Select your payment method above.', 'couponxl' ) . '</h4>';
		echo '<a href="javascript:;" class="' . ( $btn ? 'btn' : '' ) . ' modal-payment">' . $buy_now . '</a><div class="modal-payments-holder">' . $modal . '</div>';
	}
}

add_action( 'admin_init', 'couponxl_non_admin_users' );
function couponxl_non_admin_users() {
	$user_ID    = get_current_user_id();
	$user_agent = get_user_meta( $user_ID, 'user_agent', true );
	if ( ! current_user_can( 'manage_options' ) && ! stristr( $_SERVER['PHP_SELF'], 'admin-ajax.php' ) && ! stristr( $_SERVER['PHP_SELF'], 'async-upload.php' ) && ( ! $user_agent || $user_agent == 'no' ) ) {
		wp_redirect( home_url() );
		exit;
	}
}

require_once plugin_dir_path( __FILE__ ) . '/radium-one-click-demo-install/init.php';
require_once( plugin_dir_path( __FILE__ ) . '/includes/twitter_api.php' );
require_once( plugin_dir_path( __FILE__ ) . '/includes/import/import.php' );
